# CubeAI模型服务化引擎 —— AI-Boot

将AI模型推理程序封装成为Web互联网服务。

目前提供RESTful API、WebSocket和可视化Web GUI等多种形式的互联网API接口服务，支持二进制数据传输和文件上传。

## 依赖包地址 

- https://pypi.org/project/aiboot

## 依赖包引用

    $ pip install aiboot

## 应用开发实例

- CubeAI智立方

    - https://github.com/cube-ai/cubeai
    - https://code.ihub.org.cn/projects/1484/repository/cubeai_model_examples
